mailr17340 - /trunk/docs/latex/fetch_docstrings.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on August 27, 2012 - 11:43:
Author: bugman
Date: Mon Aug 27 11:43:17 2012
New Revision: 17340

URL: http://svn.gna.org/viewcvs/relax?rev=17340&view=rev
Log:
The fetch_docstrings.py now adds LaTeX labels to each user function section.

This has the form of 'uf: ' followed by the user function name, and is for 
referencing purposes
within the main text.


Modified:
    trunk/docs/latex/fetch_docstrings.py

Modified: trunk/docs/latex/fetch_docstrings.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/docs/latex/fetch_docstrings.py?rev=17340&r1=17339&r2=17340&view=diff
==============================================================================
--- trunk/docs/latex/fetch_docstrings.py (original)
+++ trunk/docs/latex/fetch_docstrings.py Mon Aug 27 11:43:17 2012
@@ -226,8 +226,8 @@
         self.uf_name_latex = replace(self.uf_name_latex, '.', '\-.')
         self.uf_name_latex = replace(self.uf_name_latex, '\_', '\-\_')
 
-        # Write out the title.
-        self.file.write("\subsection{%s}\n\n" % self.uf_name_latex)
+        # Write out the title (with label).
+        self.file.write("\subsection{%s} \label{uf: %s}\n\n" % 
(self.uf_name_latex, self.uf_name))
 
 
     def indexing(self, index, bold=False):




Related Messages


Powered by MHonArc, Updated Mon Aug 27 12:00:01 2012